import { IPipe, SourceConfig } from '@aws-cdk/aws-pipes-alpha';
import { ITableV2 } from 'aws-cdk-lib/aws-dynamodb';
import { IRole } from 'aws-cdk-lib/aws-iam';
import { DynamoDBStartingPosition } from './enums';
import { StreamSource, StreamSourceParameters } from './streamSource';
/**
 * Parameters for the DynamoDB source.
 */
export interface DynamoDBSourceParameters extends StreamSourceParameters {
    /**
     * The position in a stream from which to start reading.
     *
     * @see https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-pipes-pipe-pipesourcedynamodbstreamparameters.html#cfn-pipes-pipe-pipesourcedynamodbstreamparameters-startingposition
     */
    readonly startingPosition: DynamoDBStartingPosition;
}
/**
 * A source that reads from an DynamoDB stream.
 */
export declare class DynamoDBSource extends StreamSource {
    private readonly table;
    private readonly startingPosition;
    private readonly deadLetterTargetArn?;
    constructor(table: ITableV2, parameters: DynamoDBSourceParameters);
    bind(_pipe: IPipe): SourceConfig;
    grantRead(grantee: IRole): void;
}
